@@ -1,22 +1,20 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import unicode_literals
-
 import io
 import collections
 import re
 import functools
+import urllib.request
+import urllib.parse
 from distutils.errors import DistutilsSetupError
 from setuptools.dist import (
     _get_unpatched,
     check_package_data,
     DistDeprecationWarning,
+    check_specifier,
+    rfc822_escape,
+    rfc822_unescape,
 )
 from setuptools import sic
 from setuptools import Distribution
-from setuptools.extern.six.moves.urllib.request import pathname2url
-from setuptools.extern.six.moves.urllib_parse import urljoin
-from setuptools.extern import six
 
 from .textwrap import DALS
 from .test_easy_install import make_nspkg_sdist
@@ -29,7 +27,8 @@ def test_dist_fetch_build_egg(tmpdir):
     Check multiple calls to `Distribution.fetch_build_egg` work as expected.
     """
     index = tmpdir.mkdir('index')
-    index_url = urljoin('file://', pathname2url(str(index)))
+    index_url = urllib.parse.urljoin(
+        'file://', urllib.request.pathname2url(str(index)))
 
     def sdist_with_index(distname, version):
         dist_dir = index.mkdir(distname)
@@ -63,8 +62,7 @@ def test_dist_fetch_build_egg(tmpdir):
             dist.fetch_build_egg(r)
             for r in reqs
         ]
-    # noqa below because on Python 2 it causes flakes
-    assert [dist.key for dist in resolved_dists if dist] == reqs  # noqa
+    assert [dist.key for dist in resolved_dists if dist] == reqs
 
 
 def test_dist__get_unpatched_deprecated():
@@ -86,11 +84,8 @@ def __read_test_cases():
 
     test_cases = [
         ('Metadata version 1.0', params()),
-        ('Metadata version 1.1: Provides', params(
-            provides=['package'],
-        )),
-        ('Metadata version 1.1: Obsoletes', params(
-            obsoletes=['foo'],
+        ('Metadata Version 1.0: Short long description', params(
+            long_description='Short long description',
         )),
         ('Metadata version 1.1: Classifiers', params(
             classifiers=[
@@ -115,6 +110,10 @@ def __read_test_cases():
         ('Metadata Version 2.1: Long Description Content Type', params(
             long_description_content_type='text/x-rst; charset=UTF-8',
         )),
+        ('License', params(license='MIT', )),
+        ('License multiline', params(
+            license='This is a long license \nover multiple lines',
+        )),
         pytest.param(
             'Metadata Version 2.1: Provides Extra',
             params(provides_extras=['foo', 'bar']),
@@ -150,10 +149,7 @@ def test_read_metadata(name, attrs):
     dist_class = metadata_out.__class__
 
     # Write to PKG_INFO and then load into a new metadata object
-    if six.PY2:
-        PKG_INFO = io.BytesIO()
-    else:
-        PKG_INFO = io.StringIO()
+    PKG_INFO = io.StringIO()
 
     metadata_out.write_pkg_file(PKG_INFO)
 
@@ -169,6 +165,7 @@ def test_read_metadata(name, attrs):
         ('metadata_version', dist_class.get_metadata_version),
         ('provides', dist_class.get_provides),
         ('description', dist_class.get_description),
+        ('long_description', dist_class.get_long_description),
         ('download_url', dist_class.get_download_url),
         ('keywords', dist_class.get_keywords),
         ('platforms', dist_class.get_platforms),
@@ -254,8 +251,8 @@ def test_maintainer_author(name, attrs, tmpdir):
     with io.open(str(fn.join('PKG-INFO')), 'r', encoding='utf-8') as f:
         raw_pkg_lines = f.readlines()
 
-    # Drop blank lines
-    pkg_lines = list(filter(None, raw_pkg_lines))
+    # Drop blank lines and strip lines from default description
+    pkg_lines = list(filter(None, raw_pkg_lines[:-2]))
 
     pkg_lines_set = set(pkg_lines)
 
@@ -331,3 +328,49 @@ def test_check_package_data(package_data, expected_message):
         with pytest.raises(
                 DistutilsSetupError, match=re.escape(expected_message)):
             check_package_data(None, str('package_data'), package_data)
+
+
+def test_check_specifier():
+    # valid specifier value
+    attrs = {'name': 'foo', 'python_requires': '>=3.0, !=3.1'}
+    dist = Distribution(attrs)
+    check_specifier(dist, attrs, attrs['python_requires'])
+
+    # invalid specifier value
+    attrs = {'name': 'foo', 'python_requires': ['>=3.0', '!=3.1']}
+    with pytest.raises(DistutilsSetupError):
+        dist = Distribution(attrs)
+
+
+@pytest.mark.parametrize(
+    'content, result',
+    (
+        pytest.param(
+            "Just a single line",
+            None,
+            id="single_line",
+        ),
+        pytest.param(
+            "Multiline\nText\nwithout\nextra indents\n",
+            None,
+            id="multiline",
+        ),
+        pytest.param(
+            "Multiline\n    With\n\nadditional\n  indentation",
+            None,
+            id="multiline_with_indentation",
+        ),
+        pytest.param(
+            "  Leading whitespace",
+            "Leading whitespace",
+            id="remove_leading_whitespace",
+        ),
+        pytest.param(
+            "  Leading whitespace\nIn\n    Multiline comment",
+            "Leading whitespace\nIn\n    Multiline comment",
+            id="remove_leading_whitespace_multiline",
+        ),
+    )
+)
+def test_rfc822_unescape(content, result):
+    assert (result or content) == rfc822_unescape(rfc822_escape(content))
