@@ -1,7 +1,5 @@
-# -*- coding: utf-8 -*-
 """Easy install Tests
 """
-from __future__ import absolute_import, unicode_literals
 
 import sys
 import os
@@ -16,10 +14,12 @@ import io
 import zipfile
 import mock
 import time
-
-from setuptools.extern import six
+import re
+import subprocess
+import pathlib
 
 import pytest
+from jaraco import path
 
 from setuptools import sandbox
 from setuptools.sandbox import run_setup
@@ -28,7 +28,6 @@ from setuptools.command.easy_install import (
     EasyInstallDeprecationWarning, ScriptWriter, PthDistributions,
     WindowsScriptWriter,
 )
-from setuptools.command import easy_install as easy_install_pkg
 from setuptools.dist import Distribution
 from pkg_resources import normalize_path, working_set
 from pkg_resources import Distribution as PRDistribution
@@ -37,10 +36,17 @@ from setuptools.tests import fail_on_ascii
 import pkg_resources
 
 from . import contexts
-from .files import build_files
 from .textwrap import DALS
 
-__metaclass__ = type
+
+@pytest.fixture(autouse=True)
+def pip_disable_index(monkeypatch):
+    """
+    Important: Disable the default index for pip to avoid
+    querying packages in the index and potentially resolving
+    and installing packages there.
+    """
+    monkeypatch.setenv('PIP_NO_INDEX', 'true')
 
 
 class FakeDist:
@@ -61,35 +67,17 @@ SETUP_PY = DALS("""
 
 
 class TestEasyInstallTest:
-    def test_install_site_py(self, tmpdir):
-        dist = Distribution()
-        cmd = ei.easy_install(dist)
-        cmd.sitepy_installed = False
-        cmd.install_dir = str(tmpdir)
-        cmd.install_site_py()
-        assert (tmpdir / 'site.py').exists()
-
     def test_get_script_args(self):
         header = ei.CommandSpec.best().from_environment().as_header()
-        expected = header + DALS(r"""
-            # EASY-INSTALL-ENTRY-SCRIPT: 'spec','console_scripts','name'
-            __requires__ = 'spec'
-            import re
-            import sys
-            from pkg_resources import load_entry_point
-
-            if __name__ == '__main__':
-                sys.argv[0] = re.sub(r'(-script\.pyw?|\.exe)?$', '', sys.argv[0])
-                sys.exit(
-                    load_entry_point('spec', 'console_scripts', 'name')()
-                )
-            """)  # noqa: E501
         dist = FakeDist()
-
         args = next(ei.ScriptWriter.get_args(dist))
         name, script = itertools.islice(args, 2)
-
-        assert script == expected
+        assert script.startswith(header)
+        assert "'spec'" in script
+        assert "'console_scripts'" in script
+        assert "'name'" in script
+        assert re.search(
+            '^# EASY-INSTALL-ENTRY-SCRIPT', script, flags=re.MULTILINE)
 
     def test_no_find_links(self):
         # new option '--no-find-links', that blocks find-links added at
@@ -328,7 +316,7 @@ class TestPTHFileWriter:
         assert not pth.dirty
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def setup_context(tmpdir):
     with (tmpdir / 'setup.py').open('w') as f:
         f.write(SETUP_PY)
@@ -384,7 +372,7 @@ class TestUserInstallTest:
             f.write('Name: foo\n')
         return str(tmpdir)
 
-    @pytest.yield_fixture()
+    @pytest.fixture()
     def install_target(self, tmpdir):
         target = str(tmpdir)
         with mock.patch('sys.path', sys.path + [target]):
@@ -429,7 +417,7 @@ class TestUserInstallTest:
         )
 
 
-@pytest.yield_fixture
+@pytest.fixture
 def distutils_package():
     distutils_setup_py = SETUP_PY.replace(
         'from setuptools import setup',
@@ -468,22 +456,22 @@ class TestSetupRequires:
         """
         monkeypatch.setenv(str('PIP_RETRIES'), str('0'))
         monkeypatch.setenv(str('PIP_TIMEOUT'), str('0'))
+        monkeypatch.setenv('PIP_NO_INDEX', 'false')
         with contexts.quiet():
             # create an sdist that has a build-time dependency.
             with TestSetupRequires.create_sdist() as dist_file:
                 with contexts.tempdir() as temp_install_dir:
                     with contexts.environment(PYTHONPATH=temp_install_dir):
-                        ei_params = [
+                        cmd = [
+                            sys.executable,
+                            '-m', 'setup',
+                            'easy_install',
                             '--index-url', mock_index.url,
                             '--exclude-scripts',
                             '--install-dir', temp_install_dir,
                             dist_file,
                         ]
-                        with sandbox.save_argv(['easy_install']):
-                            # attempt to install the dist. It should
-                            # fail because it doesn't exist.
-                            with pytest.raises(SystemExit):
-                                easy_install_pkg.main(ei_params)
+                        subprocess.Popen(cmd).wait()
         # there should have been one requests to the server
         assert [r.path for r in mock_index.requests] == ['/does-not-exist/']
 
@@ -641,6 +629,7 @@ class TestSetupRequires:
     def test_setup_requires_honors_pip_env(self, mock_index, monkeypatch):
         monkeypatch.setenv(str('PIP_RETRIES'), str('0'))
         monkeypatch.setenv(str('PIP_TIMEOUT'), str('0'))
+        monkeypatch.setenv('PIP_NO_INDEX', 'false')
         monkeypatch.setenv(str('PIP_INDEX_URL'), mock_index.url)
         with contexts.save_pkg_resources_state():
             with contexts.tempdir() as temp_dir:
@@ -671,7 +660,7 @@ class TestSetupRequires:
                 dep_url = path_to_url(dep_sdist, authority='localhost')
                 test_pkg = create_setup_requires_package(
                     temp_dir,
-                    # Ignored (overriden by setup_attrs)
+                    # Ignored (overridden by setup_attrs)
                     'python-xlib', '0.19',
                     setup_attrs=dict(
                         setup_requires='dependency @ %s' % dep_url))
@@ -681,26 +670,24 @@ class TestSetupRequires:
 
     def test_setup_requires_with_allow_hosts(self, mock_index):
         ''' The `allow-hosts` option in not supported anymore. '''
+        files = {
+            'test_pkg': {
+                'setup.py': DALS('''
+                    from setuptools import setup
+                    setup(setup_requires='python-xlib')
+                    '''),
+                'setup.cfg': DALS('''
+                    [easy_install]
+                    allow_hosts = *
+                    '''),
+            }
+        }
         with contexts.save_pkg_resources_state():
             with contexts.tempdir() as temp_dir:
-                test_pkg = os.path.join(temp_dir, 'test_pkg')
-                test_setup_py = os.path.join(test_pkg, 'setup.py')
-                test_setup_cfg = os.path.join(test_pkg, 'setup.cfg')
-                os.mkdir(test_pkg)
-                with open(test_setup_py, 'w') as fp:
-                    fp.write(DALS(
-                        '''
-                        from setuptools import setup
-                        setup(setup_requires='python-xlib')
-                        '''))
-                with open(test_setup_cfg, 'w') as fp:
-                    fp.write(DALS(
-                        '''
-                        [easy_install]
-                        allow_hosts = *
-                        '''))
+                path.build(files, prefix=temp_dir)
+                setup_py = str(pathlib.Path(temp_dir, 'test_pkg', 'setup.py'))
                 with pytest.raises(distutils.errors.DistutilsError):
-                    run_setup(test_setup_py, [str('--version')])
+                    run_setup(setup_py, [str('--version')])
         assert len(mock_index.requests) == 0
 
     def test_setup_requires_with_python_requires(self, monkeypatch, tmpdir):
@@ -743,7 +730,7 @@ class TestSetupRequires:
         with contexts.save_pkg_resources_state():
             test_pkg = create_setup_requires_package(
                 str(tmpdir),
-                'python-xlib', '0.19',  # Ignored (overriden by setup_attrs).
+                'python-xlib', '0.19',  # Ignored (overridden by setup_attrs).
                 setup_attrs=dict(
                     setup_requires='dep', dependency_links=[index_url]))
             test_setup_py = os.path.join(test_pkg, 'setup.py')
@@ -753,10 +740,10 @@ class TestSetupRequires:
         assert eggs == ['dep 1.0']
 
     @pytest.mark.parametrize(
-        'use_legacy_installer,with_dependency_links_in_setup_py',
-        itertools.product((False, True), (False, True)))
+        'with_dependency_links_in_setup_py',
+        (False, True))
     def test_setup_requires_with_find_links_in_setup_cfg(
-            self, monkeypatch, use_legacy_installer,
+            self, monkeypatch,
             with_dependency_links_in_setup_py):
         monkeypatch.setenv(str('PIP_RETRIES'), str('0'))
         monkeypatch.setenv(str('PIP_TIMEOUT'), str('0'))
@@ -778,11 +765,9 @@ class TestSetupRequires:
                     fp.write(DALS(
                         '''
                         from setuptools import installer, setup
-                        if {use_legacy_installer}:
-                            installer.fetch_build_egg = installer._legacy_fetch_build_egg
                         setup(setup_requires='python-xlib==42',
                         dependency_links={dependency_links!r})
-                        ''').format(use_legacy_installer=use_legacy_installer,  # noqa
+                        ''').format(
                                     dependency_links=dependency_links))
                 with open(test_setup_cfg, 'w') as fp:
                     fp.write(DALS(
@@ -808,7 +793,7 @@ class TestSetupRequires:
                 # Create source tree for `dep`.
                 dep_pkg = os.path.join(temp_dir, 'dep')
                 os.mkdir(dep_pkg)
-                build_files({
+                path.build({
                     'setup.py':
                     DALS("""
                           import setuptools
@@ -1001,8 +986,6 @@ def create_setup_requires_package(path, distname='foobar', version='0.1',
 )
 class TestScriptHeader:
     non_ascii_exe = '/Users/José/bin/python'
-    if six.PY2:
-        non_ascii_exe = non_ascii_exe.encode('utf-8')
     exe_with_spaces = r'C:\Program Files\Python36\python.exe'
 
     def test_get_script_header(self):
